CKIP E-HowNet Tools
===================

Git
---

https://github.com/emfomy/ehownet

|GitHub Version| |GitHub Release| |GitHub Issues|

.. |GitHub Version| image:: https://img.shields.io/github/release/emfomy/ehownet/all.svg?maxAge=3600
   :target: https://github.com/emfomy/ehownet/releases

.. |GitHub License| image:: https://img.shields.io/github/license/emfomy/ehownet.svg?maxAge=3600
   :target: https://github.com/emfomy/ehownet/blob/master/LICENSE

.. |GitHub Release| image:: https://img.shields.io/github/release-date/emfomy/ehownet.svg?maxAge=3600

.. |GitHub Downloads| image:: https://img.shields.io/github/downloads/emfomy/ehownet/total.svg?maxAge=3600
   :target: https://github.com/emfomy/ehownet/releases/latest

.. |GitHub Issues| image:: https://img.shields.io/github/issues/emfomy/ehownet.svg?maxAge=3600
   :target: https://github.com/emfomy/ehownet/issues

.. |GitHub Forks| image:: https://img.shields.io/github/forks/emfomy/ehownet.svg?style=social&label=Fork&maxAge=3600

.. |GitHub Stars| image:: https://img.shields.io/github/stars/emfomy/ehownet.svg?style=social&label=Star&maxAge=3600

.. |GitHub Watchers| image:: https://img.shields.io/github/watchers/emfomy/ehownet.svg?style=social&label=Watch&maxAge=3600

PyPI
----

https://pypi.org/project/ehownet

|PyPI Version| |PyPI License| |PyPI Downloads| |PyPI Python| |PyPI Implementation| |PyPI Status|

.. |PyPI Version| image:: https://img.shields.io/pypi/v/ehownet.svg?maxAge=3600
   :target: https://pypi.org/project/ehownet

.. |PyPI License| image:: https://img.shields.io/pypi/l/ehownet.svg?maxAge=3600
   :target: https://github.com/emfomy/ehownet/blob/master/LICENSE

.. |PyPI Downloads| image:: https://img.shields.io/pypi/dm/ehownet.svg?maxAge=3600
   :target: https://pypi.org/project/ehownet#files

.. |PyPI Python| image:: https://img.shields.io/pypi/pyversions/ehownet.svg?maxAge=3600

.. |PyPI Implementation| image:: https://img.shields.io/pypi/implementation/ehownet.svg?maxAge=3600

.. |PyPI Format| image:: https://img.shields.io/pypi/format/ehownet.svg?maxAge=3600

.. |PyPI Status| image:: https://img.shields.io/pypi/status/ehownet.svg?maxAge=3600

Documentation
-------------

https://ehownet.readthedocs.io/

|ReadTheDocs Home|

.. |ReadTheDocs Home| image:: https://img.shields.io/website/https/ehownet.readthedocs.io.svg?maxAge=3600&up_message=online&down_message=offline
   :target: https://ehownet.readthedocs.io

Related Websites
----------------

- E-HowNet Website http://ehownet.iis.sinica.edu.tw
- E-HowNet Visualization Demo https://ckip.iis.sinica.edu.tw/service/ehnvis

Author
------

* Mu Yang <https://muyang.pro>

Requirements
------------

* `Python <https://www.python.org>`__ 3.6+
* `PLY (Python Lex-Yacc) <https://www.dabeaz.com/ply>`__ 3.11+
* `TreeLib <https://treelib.readthedocs.io>`__ 1.6.0+
* `wcwidth <https://pypi.org/project/wcwidth>`__ 0.2.5+
* `dataclasses <https://pypi.org/project/dataclasses/>`__ (Python 3.6 only)

Installation
------------

.. code-block:: bash

   pip install -U ehownet

One may download the database file manually from https://ckip.iis.sinica.edu.tw/CKIP/ehownet_reg/ .

License
-------

|GPL-3.0|

Copyright (c) 2020 `CKIP Lab <https://ckip.iis.sinica.edu.tw>`__ under the `GPL-3.0 License <https://www.gnu.org/licenses/gpl-3.0.html>`__.

.. |GPL-3.0| image:: https://www.gnu.org/graphics/gplv3-with-text-136x68.png
   :target: https://www.gnu.org/licenses/gpl-3.0.html
